import { useQuery } from '@tanstack/vue-query';
import { useLifeRechargeContext, CreateEditPayChannelsInput } from '@life-payment/core-vue';

export function useOnlineService() {
  const { blLifeRecharge } = useLifeRechargeContext();

  const { data } = useQuery({
    queryKey: ['blLifeRecharge/getOnlineService'],
    queryFn: async () => {
      return await blLifeRecharge.services.getOnlineService({
        showLoading: false,
      });
    },
    placeholderData: () => '',
  });

  return {
    onlineServiceLink: data,
  };
}

type UseLifePayChannlesAllListOptions = {
  onSuccess?: (data: API.CreateEditPayChannelsInput[]) => any;
};

export function useLifePayChannlesAllList(options: UseLifePayChannlesAllListOptions = {}) {
  const { onSuccess } = options;

  const { blLifeRecharge } = useLifeRechargeContext();

  const {
    data: allChannlesList,
    isLoading,
    refetch,
  } = useQuery({
    queryKey: ['blLifeRecharge/getLifePayChannlesAllList'],
    queryFn: async () => {
      return await blLifeRecharge.services.getLifePayChannlesAllList({
        showLoading: false,
      });
    },
    placeholderData: () => [] as CreateEditPayChannelsInput[],
    onSuccess: (data) => {
      onSuccess?.(data);
    },
  });

  function getChannlesNameByNum(channlesNum: string) {
    return (
      allChannlesList.value.find((item) => item.channlesNum === channlesNum)?.channlesName ?? ''
    );
  }

  return {
    allChannlesList,
    isLoading,
    refetch,
    getChannlesNameByNum,
  };
}
